==> firefox-36.0.source.tar.bz2: mozilla-release/browser/devtools/performance/test/browser_perf-front-basic-timeline-01.js <==
/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

/**
 * Test basic functionality of PerformanceFront, retrieving timeline data.
 */

function spawnTest () {
  Services.prefs.setBoolPref("devtools.performance.ui.show-timeline-memory", true);

  let { target, front } = yield initBackend(SIMPLE_URL);

  let lastMemoryDelta = 0;
  let lastTickDelta = 0;

  let counters = {
    markers: [],
    memory: [],
    ticks: []
  };

  let deferreds = {
    markers: Promise.defer(),
    memory: Promise.defer(),
    ticks: Promise.defer()
  }

  front.on("markers", handler);
  front.on("memory", handler);
  front.on("ticks", handler);

  yield front.startRecording();

  yield Promise.all(Object.keys(deferreds).map(type => deferreds[type].promise));

  yield front.stopRecording();

  is(counters.markers.length, 1, "one marker event fired.");
  is(counters.memory.length, 3, "three memory events fired.");
  is(counters.ticks.length, 3, "three ticks events fired.");

  yield removeTab(target.tab);
  finish();

  function handler (name, ...args) {
    if (name === "memory") {
      let [delta, measurement] = args;
      is(typeof delta, "number", "received `delta` in memory event");
      ok(delta > lastMemoryDelta, "received `delta` in memory event");
      ok(measurement.total, "received `total` in memory event");
      ok(measurement.domSize, "received `domSize` in memory event");
      ok(measurement.jsObjectsSize, "received `jsObjectsSize` in memory event");

      counters.memory.push({ delta: delta, measurement: measurement });
      lastMemoryDelta = delta;
    } else if (name === "ticks") {
      let [delta, timestamps] = args;
      ok(delta > lastTickDelta, "received `delta` in ticks event");

      // First tick doesn't contain any timestamps
      if (counters.ticks.length) {
        ok(timestamps.length, "received `timestamps` in ticks event");
      }

      counters.ticks.push({ delta: delta, timestamps: timestamps});
      lastTickDelta = delta;
    } else if (name === "markers") {
      let [markers] = args;
      ok(markers[0].start, "received atleast one marker with `start`");
      ok(markers[0].end, "received atleast one marker with `end`");
      ok(markers[0].name, "received atleast one marker with `name`");
      counters.markers.push(markers);
      front.off(name, handler);
      deferreds[name].resolve();
    } else {
      throw new Error("unknown event");
    }

    if (name !== "markers" && counters[name].length === 3) {
      front.off(name, handler);
      deferreds[name].resolve();
    }
  };
}

==> firefox-40.0.3.source.tar.bz2: mozilla-release/browser/devtools/performance/test/browser_perf-front-basic-timeline-01.js <==
/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

/**
 * Test basic functionality of PerformanceFront, retrieving timeline data.
 */

function spawnTest () {
  let { target, front } = yield initBackend(SIMPLE_URL);

  let lastMemoryDelta = 0;
  let lastTickDelta = 0;

  let counters = {
    markers: [],
    memory: [],
    ticks: []
  };

  let deferreds = {
    markers: Promise.defer(),
    memory: Promise.defer(),
    ticks: Promise.defer()
  };

  front.on("timeline-data", handler);

  yield front.startRecording({ withMarkers: true, withMemory: true, withTicks: true });
  yield Promise.all(Object.keys(deferreds).map(type => deferreds[type].promise));
  yield front.stopRecording();
  front.off("timeline-data", handler);

  is(counters.markers.length, 1, "one marker event fired.");
  is(counters.memory.length, 3, "three memory events fired.");
  is(counters.ticks.length, 3, "three ticks events fired.");

  yield removeTab(target.tab);
  finish();

  function handler (_, name, ...args) {
    if (name === "markers") {
      if (counters.markers.length >= 1) { return; }
      let [markers] = args;
      ok(markers[0].start, "received atleast one marker with `start`");
      ok(markers[0].end, "received atleast one marker with `end`");
      ok(markers[0].name, "received atleast one marker with `name`");

      counters.markers.push(markers);
    }
    else if (name === "memory") {
      if (counters.memory.length >= 3) { return; }
      let [delta, measurement] = args;
      is(typeof delta, "number", "received `delta` in memory event");
      ok(delta > lastMemoryDelta, "received `delta` in memory event");
      ok(measurement.total, "received `total` in memory event");

      counters.memory.push({ delta, measurement });
      lastMemoryDelta = delta;
    }
    else if (name === "ticks") {
      if (counters.ticks.length >= 3) { return; }
      let [delta, timestamps] = args;
      ok(delta > lastTickDelta, "received `delta` in ticks event");

      // Timestamps aren't guaranteed to always contain tick events, since
      // they're dependent on the refresh driver, which may be blocked.

      counters.ticks.push({ delta, timestamps });
      lastTickDelta = delta;
    }
    else {
      throw new Error("unknown event " + name);
    }

    if (name === "markers" && counters[name].length === 1 ||
        name === "memory" && counters[name].length === 3 ||
        name === "ticks" && counters[name].length === 3) {
      deferreds[name].resolve();
    }
  };
}
